@@ -2,7 +2,7 @@
 # pylint: disable=missing-docstring
 import sys
 
-from foran.cli import main
+from foran.cli import app
 
 if __name__ == '__main__':
-    sys.exit(main(sys.argv[1:]))  # pragma: no cover
+    sys.exit(app(prog_name='foran'))  # pragma: no cover
