@@ -3,6 +3,7 @@
 """In front or behind (Foran eller bagved)? reporting interface."""
 import pathlib
 from enum import Enum, auto
+from typing import Tuple
 
 from foran.status import Status
 
@@ -25,6 +26,10 @@ class Report:
 
 def report_as(status: Status, report: Report) -> None:
     """Side effects ..."""
+    if report.stem == 'STD_OUT':
+        print(''.join(generate_report(status)))
+        return
+
     file_extension = '.txt' if report.file_format == Format.TEXT else ''  # TODO(sthagen) HACK A DID ACK
     filepath = pathlib.Path(f'{report.stem}{file_extension}')
     filepath.parent.mkdir(parents=True, exist_ok=True)
@@ -33,7 +38,7 @@ def report_as(status: Status, report: Report) -> None:
         handle.write(''.join(generate_report(status)))
 
 
-def generate_report(status: Status) -> tuple[str, ...]:
+def generate_report(status: Status) -> Tuple[str, ...]:
     """Convoluted special trickery ... to build partially conditional report lines"""
     report = []
     report.append(f'Analysis ({status.when})\n')
@@ -45,6 +50,10 @@ def generate_report(status: Status) -> tuple[str, ...]:
         report.append('List of local commits:\n')
         report.append(''.join(f' - {commit}\n' for commit in status.local_commits))
 
+    if status.local_staged:
+        report.append('List of locally staged files: \n')
+        report.append(''.join(f' - {staged_file}\n' for staged_file in status.local_staged))
+
     if status.local_files:
         report.append('List of locally modified files: \n')
         report.append(''.join(f' - {mod_file}\n' for mod_file in status.local_files))
